@@ -5,6 +5,7 @@ pub use self::contact_ball_ball::contact_ball_ball;
 pub use self::contact_ball_convex_polyhedron::{
     contact_ball_convex_polyhedron, contact_convex_polyhedron_ball,
 };
+#[cfg(feature = "std")]
 pub use self::contact_composite_shape_shape::{
     contact_composite_shape_shape, contact_shape_composite_shape,
 };
@@ -13,14 +14,18 @@ pub use self::contact_halfspace_support_map::{
     contact_halfspace_support_map, contact_support_map_halfspace,
 };
 pub use self::contact_shape_shape::contact;
-pub use self::contact_support_map_support_map::contact_support_map_support_map;
-pub use self::contact_support_map_support_map::contact_support_map_support_map_with_params;
+#[cfg(feature = "std")] // TODO: doesn’t work without std because of EPA
+pub use self::contact_support_map_support_map::{
+    contact_support_map_support_map, contact_support_map_support_map_with_params,
+};
 
 mod contact;
 mod contact_ball_ball;
 mod contact_ball_convex_polyhedron;
+#[cfg(feature = "std")]
 mod contact_composite_shape_shape;
 mod contact_cuboid_cuboid;
 mod contact_halfspace_support_map;
 mod contact_shape_shape;
+#[cfg(feature = "std")] // TODO: doesn’t work without std because of EPA
 mod contact_support_map_support_map;
