@@ -5,9 +5,17 @@ use crate::shape::SupportMap;
 use na;
 use num::Zero;
 
+#[cfg(not(feature = "std"))]
+use na::RealField; // for .copysign()
+
 /// Cone shape with its principal axis aligned with the `y` axis.
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+#[cfg_attr(
+    all(not(target_os = "cuda"), feature = "cuda"),
+    derive(cust::DeviceCopy)
+)]
 #[derive(PartialEq, Debug, Copy, Clone)]
+#[repr(C)]
 pub struct Cone {
     /// The half-height of the cone.
     pub half_height: Real,
