@@ -17,6 +17,12 @@ pub mod vhacd;
 /// Voxelization of a 2D polyline or 3D triangle mesh.
 pub mod voxelization;
 
+#[cfg(feature = "dim2")]
+pub(crate) mod ear_clipping;
+#[cfg(feature = "dim2")]
+pub(crate) mod hertel_mehlhorn;
+#[cfg(feature = "dim2")]
+pub use hertel_mehlhorn::{hertel_mehlhorn, hertel_mehlhorn_idx};
 #[cfg(feature = "dim2")]
 mod to_polyline;
 #[cfg(feature = "dim3")]
