@@ -2,9 +2,11 @@
 
 pub use self::ccw_face_normal::ccw_face_normal;
 pub use self::center::center;
+#[cfg(feature = "std")]
 pub use self::deterministic_state::DeterministicState;
 
 #[cfg(feature = "dim3")]
+#[cfg(feature = "std")]
 pub use self::cleanup::remove_unused_points;
 pub(crate) use self::inv::inv;
 pub use self::isometry_ops::{IsometryOps, IsometryOpt};
@@ -17,8 +19,11 @@ pub use self::sdp_matrix::{SdpMatrix2, SdpMatrix3};
 
 pub use self::as_bytes::AsBytes;
 pub(crate) use self::consts::*;
-pub use self::cov::cov;
+pub use self::cov::{center_cov, cov};
 pub use self::hashable_partial_eq::HashablePartialEq;
+#[cfg(feature = "std")]
+pub use self::interval::{find_root_intervals, find_root_intervals_to, Interval, IntervalFunction};
+pub use self::obb::obb;
 #[cfg(feature = "dim3")]
 pub(crate) use self::sort::sort2;
 pub(crate) use self::sort::sort3;
@@ -30,17 +35,25 @@ mod as_bytes;
 mod ccw_face_normal;
 mod center;
 #[cfg(feature = "dim3")]
+#[cfg(feature = "std")]
 mod cleanup;
 mod consts;
 mod cov;
+#[cfg(feature = "std")]
 mod deterministic_state;
 mod hashable_partial_eq;
+#[cfg(feature = "std")]
 pub mod hashmap;
+#[cfg(feature = "std")]
+mod interval;
 mod inv;
 mod isometry_ops;
 mod median;
+mod obb;
 mod point_cloud_support_point;
 mod point_in_poly2d;
+#[cfg(feature = "dim2")]
+pub mod point_in_triangle;
 mod ref_with_cost;
 mod sdp_matrix;
 mod sort;
